##
# This file is part of WhatWeb and may be subject to
# redistribution and commercial restrictions. Please see the WhatWeb
# web site for more information on licensing and terms of use.
# https://www.morningstarsecurity.com/research/whatweb
##
Plugin.define do
name "ez-oscommerce"
authors [
  "Brendan Coles <bcoles@gmail.com>", # 2010-10-12
]
version "0.1"
description "PHP powered shopping cart"
website "http://www.eptcel.com.br/"

# 1 result for "powered by ez oscommerce" @ 2010-10-12


matches [

{ :text=>'Powered by <a href="http://www.eptcel.com.br" target="_blank">ez oscommerce</a>' },

]

end

